pub enum MidiMessage {
Show 17 variants NoteOff(ChannelNoteValue7), NoteOn(ChannelNoteValue7), KeyPressure(ChannelNoteValue7), ControlChange(ChannelControlValue7), ProgramChange(ChannelProgram), ChannelPressure(ChannelValue7), PitchBendChange(ChannelValue14), QuarterFrame(QuarterFrame), SongPositionPointer(Value14), SongSelect(Value7), TuneRequest, TimingClock, Start, Continue, Stop, ActiveSensing, Reset,
}
An enum with variants for all possible Midi messages.

Variants

NoteOff(ChannelNoteValue7)

Note Off message

NoteOn(ChannelNoteValue7)

Note on message

KeyPressure(ChannelNoteValue7)

KeyPressure message for polyphonic aftertouch

ControlChange(ChannelControlValue7)

Control change message

ProgramChange(ChannelProgram)

Program change message

ChannelPressure(ChannelValue7)

Channel pressure message for channel aftertouch

PitchBendChange(ChannelValue14)

Pitch bend message

QuarterFrame(QuarterFrame)

System exclusive message starts System exclusive data is received Signals the end of the system exclusive block Midi time code quarter frame

SongPositionPointer(Value14)

Set the song position pointer

SongSelect(Value7)

Specifies which sequence or song is to be played

TuneRequest

Tune all oscillators

TimingClock

Timing tick message

Start

Start message

Continue

Continue message

Stop

Stop message

ActiveSensing

Active sensing message

Reset

Reset message

Implementations

The length of the rendered data, including the status