Channel

Struct Channel 

pub struct Channel(/* private fields */);
Represents a Midi channel, Midi channels can range from 0 to 15, but are represented as 1 based values Channel 1 to 16

Implementations

Source

impl Channel

pub const C1: Self

MIDI channel 1

pub const C2: Self

MIDI channel 2

pub const C3: Self

MIDI channel 3

pub const C4: Self

MIDI channel 4

pub const C5: Self

MIDI channel 5

pub const C6: Self

MIDI channel 6

pub const C7: Self

MIDI channel 7

pub const C8: Self

MIDI channel 8

pub const C9: Self

MIDI channel 9

pub const C10: Self

MIDI channel 10

pub const C11: Self

MIDI channel 11

pub const C12: Self

MIDI channel 12

pub const C13: Self

MIDI channel 13

pub const C14: Self

MIDI channel 14

pub const C15: Self

MIDI channel 15

pub const C16: Self

MIDI channel 16

pub const MIN: Self = Self::C1

The minimum MIDI channel

pub const MAX: Self = Self::C16

The maximum MIDI channel

pub const fn new(channel: u8) -> Self

Create a new Channel

Arguments
  • channel - the 0 based channel value
Note
  • The channel will be clamped so it is in the 0..15 valid range.