Note

Struct Note 

pub struct Note(/* private fields */);
Represents a midi note number

Note

  • 12-tone english named note constants are calculated with 0 corresponding to C-2 and 127 to G8, C4 is 72

Implementations

Source

impl Note

pub const C2m: Self

pub const Cs2m: Self

pub const D2m: Self

pub const Ds2m: Self

pub const E2m: Self

pub const F2m: Self

pub const Fs2m: Self

pub const G2m: Self

pub const Gs2m: Self

pub const A2m: Self

pub const As2m: Self

pub const B2m: Self

pub const C1m: Self

pub const Cs1m: Self

pub const D1m: Self

pub const Ds1m: Self

pub const E1m: Self

pub const F1m: Self

pub const Fs1m: Self

pub const G1m: Self

pub const Gs1m: Self

pub const A1m: Self

pub const As1m: Self

pub const B1m: Self

pub const C0: Self

pub const Cs0: Self

pub const D0: Self

pub const Ds0: Self

pub const E0: Self

pub const F0: Self

pub const Fs0: Self

pub const G0: Self

pub const Gs0: Self

pub const A0: Self

pub const As0: Self

pub const B0: Self

pub const C1: Self

pub const Cs1: Self

pub const D1: Self

pub const Ds1: Self

pub const E1: Self

pub const F1: Self

pub const Fs1: Self

pub const G1: Self

pub const Gs1: Self

pub const A1: Self

pub const As1: Self

pub const B1: Self

pub const C2: Self

pub const Cs2: Self

pub const D2: Self

pub const Ds2: Self

pub const E2: Self

pub const F2: Self

pub const Fs2: Self

pub const G2: Self

pub const Gs2: Self

pub const A2: Self

pub const As2: Self

pub const B2: Self

pub const C3: Self

pub const Cs3: Self

pub const D3: Self

pub const Ds3: Self

pub const E3: Self

pub const F3: Self

pub const Fs3: Self

pub const G3: Self

pub const Gs3: Self

pub const A3: Self

pub const As3: Self

pub const B3: Self

pub const C4: Self

pub const Cs4: Self

pub const D4: Self

pub const Ds4: Self

pub const E4: Self

pub const F4: Self

pub const Fs4: Self

pub const G4: Self

pub const Gs4: Self

pub const A4: Self

pub const As4: Self

pub const B4: Self

pub const C5: Self

pub const Cs5: Self

pub const D5: Self

pub const Ds5: Self

pub const E5: Self

pub const F5: Self

pub const Fs5: Self

pub const G5: Self

pub const Gs5: Self

pub const A5: Self

pub const As5: Self

pub const B5: Self

pub const C6: Self

pub const Cs6: Self

pub const D6: Self

pub const Ds6: Self

pub const E6: Self

pub const F6: Self

pub const Fs6: Self

pub const G6: Self

pub const Gs6: Self

pub const A6: Self

pub const As6: Self

pub const B6: Self

pub const C7: Self

pub const Cs7: Self

pub const D7: Self

pub const Ds7: Self

pub const E7: Self

pub const F7: Self

pub const Fs7: Self

pub const G7: Self

pub const Gs7: Self

pub const A7: Self

pub const As7: Self

pub const B7: Self

pub const C8: Self

pub const Cs8: Self

pub const D8: Self

pub const Ds8: Self

pub const E8: Self

pub const F8: Self

pub const Fs8: Self

pub const G8: Self

pub const MIN: Self = Self::C2m

The minimum note value

pub const MAX: Self = Self::G8

The maximum note value

pub const fn new(val: u8) -> Self

Create a new Note

Arguments
  • val - the note number value
Note
  • The val will be clamped so it is in the 0..127 valid range